@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -9,8 +9,8 @@
 #include "../contenttypewidget.h"
 #include <QComboBox>
 #include <QLabel>
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
 ContentTypeWidgetTest::ContentTypeWidgetTest(QObject *parent)
     : QObject(parent)
 {
@@ -23,9 +23,9 @@ ContentTypeWidgetTest::~ContentTypeWidgetTest()
 void ContentTypeWidgetTest::shouldHaveDefaultValue()
 {
     PimCommon::ContentTypeWidget widget;
-    auto *label = widget.findChild<QLabel *>(QStringLiteral("contenttypewidgetlabel"));
+    auto label = widget.findChild<QLabel *>(QStringLiteral("contenttypewidgetlabel"));
     QVERIFY(label);
-    auto *combo = widget.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
+    auto combo = widget.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
     QVERIFY(combo);
     QVERIFY(combo->count() > 0);
     QCOMPARE(widget.currentIndex(), 0);
@@ -34,7 +34,7 @@ void ContentTypeWidgetTest::shouldHaveDefaultValue()
 void ContentTypeWidgetTest::shouldChangeComboBoxIndex()
 {
     PimCommon::ContentTypeWidget contentType;
-    auto *combo = contentType.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
+    auto combo = contentType.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
     for (int i = 0; i < combo->count(); ++i) {
         contentType.setCurrentIndex(i);
         QCOMPARE(contentType.currentIndex(), i);
@@ -49,8 +49,8 @@ void ContentTypeWidgetTest::shouldEmitSignalWhenIndexChanged()
     QVERIFY(QTest::qWaitForWindowExposed(&contentType));
     QSignalSpy spy(&contentType, &PimCommon::ContentTypeWidget::activated);
     contentType.setCurrentIndex(1);
-    //FIXME
-    //QCOMPARE(spy.at(0).count(), 1);
+    // FIXME
+    // QCOMPARE(spy.at(0).count(), 1);
 }
 
 void ContentTypeWidgetTest::shouldChangeItem()
@@ -58,7 +58,7 @@ void ContentTypeWidgetTest::shouldChangeItem()
     PimCommon::ContentTypeWidget contentType;
     contentType.show();
     QVERIFY(QTest::qWaitForWindowExposed(&contentType));
-    auto *combo = contentType.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
+    auto combo = contentType.findChild<QComboBox *>(QStringLiteral("contentcombobox"));
     for (int i = 0; i < combo->count(); ++i) {
         contentType.setCurrentIndex(i);
         QCOMPARE(contentType.currentText(), combo->currentText());
