@@ -1,25 +1,26 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CHECKEDCOLLECTIONWIDGET_H
-#define CHECKEDCOLLECTIONWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "pimcommonakonadi_export.h"
+#include <QWidget>
 
 class QItemSelectionModel;
 class QTreeView;
 class KCheckableProxyModel;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class EntityTreeModel;
 class Collection;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class CheckedCollectionWidgetPrivate;
 /**
  * @brief The CheckedCollectionWidget class
@@ -30,7 +31,7 @@ class PIMCOMMONAKONADI_EXPORT CheckedCollectionWidget : public QWidget
     Q_OBJECT
 public:
     explicit CheckedCollectionWidget(const QString &mimetype, QWidget *parent = nullptr);
-    ~CheckedCollectionWidget();
+    ~CheckedCollectionWidget() override;
 
     Q_REQUIRED_RESULT Akonadi::EntityTreeModel *entityTreeModel() const;
 
@@ -50,4 +51,3 @@ private:
 };
 }
 
-#endif // CHECKEDCOLLECTIONWIDGET_H
